var SHEditor;
(function(SHEditor) {
  /**
   * 输入文字标签变化
   *
   * @export
   */
  function onTextTagChanged(handler) {
    SHJSBridge.addEventListener('textTagChange', function(content) {
      handler(content);
    });
  }
  SHEditor.onTextTagChanged = onTextTagChanged;
  /**
   * 通知客户端编辑内容初始化完成
   *
   * @export
   */
  function triggerContentInitiated(content) {
    SHJSBridge.sendMessage('contentInitiated', content);
  }
  SHEditor.triggerContentInitiated = triggerContentInitiated;
  /**
   * 通知客户端调起弹窗
   *
   * @export
   */
  function triggerCallDialog(message) {
    SHJSBridge.sendMessage('callDialog', message);
  }
  SHEditor.triggerCallDialog = triggerCallDialog;
  /**
   * 弹窗点击
   *
   * @export
   */
  function onDialogButtonClicked(handler) {
    SHJSBridge.addEventListener('dialogButtonClicked', function(content) {
      handler(content);
    });
  }
  SHEditor.onDialogButtonClicked = onDialogButtonClicked;
  /**
   * 通知客户端标签变化
   *
   * @export
   */
  function triggerTextTagChange(tagStatus) {
    SHJSBridge.sendMessage('textTagChange', tagStatus);
  }
  SHEditor.triggerTextTagChange = triggerTextTagChange;

  /**
   * 通知客户端js已准备好
   *
   * @export
   */
  function triggerWebviewJSReady() {
    SHJSBridge.sendMessage('webviewJSReady', {});
  }
  SHEditor.triggerWebviewJSReady = triggerWebviewJSReady;

  SHEditor.VisibleSize = {
    width: 0,
    height: 0,
  };
  SHJSBridge.addEventListener('updateVisibleSize', function(content) {
    SHEditor.VisibleSize = content;
  });
  function onRichTextContentUpdate(handler) {
    SHJSBridge.addEventListener('updateRichTextContent', function(htmlString) {
      handler(htmlString);
    });
  }
  SHEditor.onRichTextContentUpdate = onRichTextContentUpdate;
  function getRichTextContent(handler) {
    SHJSBridge.addEventListener('getRichTextContent', function(
      content,
      complete
    ) {
      handler(function(htmlString) {
        complete(htmlString);
      });
    });
  }
  SHEditor.getRichTextContent = getRichTextContent;
  function updateTextCount(textCount) {
    SHJSBridge.sendMessage('textCountChange', textCount);
  }
  SHEditor.updateTextCount = updateTextCount;
})(SHEditor || (SHEditor = {}));
var SHEditor;
(function(SHEditor) {
  var ImageStatus;
  (function(ImageStatus) {
    ImageStatus[(ImageStatus['uploading'] = 0)] = 'uploading';
    ImageStatus[(ImageStatus['failed'] = 1)] = 'failed';
    ImageStatus[(ImageStatus['success'] = 2)] = 'success';
  })((ImageStatus = SHEditor.ImageStatus || (SHEditor.ImageStatus = {})));

  function ImageContext(data) {
    this.token = data.token;
    this.size = data.size;
    this.status = data.status;
    this.url = data.url;
    this.onDelete = data.onDelete;
  }
  ImageContext.prototype.retry = function() {
    if (this.status == ImageStatus.success && this.url) {
      console.warn(`图片已经上传成功了！URL: ${this.url}`);
      return;
    }
    SHJSBridge.sendMessage('uploadImage', { token: this.token });
  };
  ImageContext.prototype.delete = function() {
    this.onDelete(this);
    SHJSBridge.sendMessage('deleteImage', { token: this.token });
  };
  ImageContext.prototype.edit = function() {
    SHJSBridge.sendMessage('editImage', { token: this.token });
  };
  SHEditor.ImageContext = ImageContext;
  function createUUID() {
    return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function(c) {
      var r = (Math.random() * 16) | 0,
        v = c == 'x' ? r : (r & 0x3) | 0x8;
      return v.toString(16);
    });
  }
  function ImageManager() {
    this.imageContextList = {};
    var self = this;
    SHJSBridge.addEventListener(`imageStatusChange`, function(content) {
      var token = content.token;
      var context = self.imageContextList[token];
      if (context === undefined) {
        context = new ImageContext(
          Object.myAssign(content, {
            onDelete: function(ctx) {
              self.deleteImageWithContext(ctx);
            },
          })
        );
        self.imageContextList[token] = context;
        self.insertImageHandler(context);
      } else {
        context.status = content.status;
        context.size = content.size;
        context.url = content.url;
        context.error = content.error;
        if (context.onStatusChange) {
          context.onStatusChange();
        }
      }
    });
  }
  ImageManager.prototype.insertImageWithContext = function(handler) {
    this.insertImageHandler = handler;
  };
  ImageManager.prototype.deleteImageWithContext = function(context) {
    delete this.imageContextList[context.token];
  };
  ImageManager.prototype.createImageContext = function(content) {
    var self = this;
    var context = new ImageContext(
      Object.myAssign(content, {
        token: createUUID(),
        status: ImageStatus.success,
        onDelete: function(ctx) {
          self.deleteImageWithContext(ctx);
        },
      })
    );
    self.imageContextList[context.token] = context;
    SHJSBridge.sendMessage('createImageContext', {
      token: context.token,
      size: context.size,
      url: context.url,
      status: ImageStatus.success,
    });
    return context;
  };
  var imageManager = new ImageManager();
  function onImageInsert(handler) {
    imageManager.insertImageWithContext(handler);
  }
  SHEditor.onImageInsert = onImageInsert;
  function createImageContext(content) {
    return imageManager.createImageContext(content);
  }
  SHEditor.createImageContext = createImageContext;
})(SHEditor || (SHEditor = {}));
